@@ -2,5 +2,5 @@ from entsoe_client.Clients import Client
 from entsoe_client.Queries import Query
 from entsoe_client.Parsers import Parser
 
-__version__ = '0.1.1'
-__all__ = ['Client', 'Query', 'Parser']
+__version__ = "0.1.4"
+__all__ = ["Client", "Query", "Parser"]
